@@ -44,20 +44,23 @@ class GitIssuePublisher(Publisher):
             raise
 
 
-    def publish(self, body: str):
+    def publish(self, data):
         """
         Publishes or updates an issue with the graph and body content.
 
-        :param body: The body text for the issue.
-        :param values: A list of integer values to include in the graph.
-        :return: The existing or newly created issue.
+        :param data: The body for the issue.
+        :return: None
         """
         try:
             title = f"Automated Issue on branch {self.branch}"
+
             existing_issue = self.get_thread(title)
+
             main_comment = existing_issue.get_comments()[0]
-            print(main_comment)
-            existing_issue.create_comment(body)
+            updated_body = self.append_data_to_comment(main_comment.body, data['message']['adherence'])
+            main_comment.edit(updated_body)
+
+            existing_issue.create_comment(self.generate_report(data))
 
             return 
         except GithubException as e:
@@ -90,6 +93,7 @@ class GitIssuePublisher(Publisher):
                 return existing_issue
 
             # If no issue is found, create a new one
+            # This creates the first comment... this is where we are going to have the summary built with markdown
             new_issue = repo.create_issue(title=title, body=body, assignee=self.user)
             return new_issue
 
@@ -106,15 +110,12 @@ class GitIssuePublisher(Publisher):
             f"- **Provided:** {data['message']['provided']}",
             f"- **Generated:** {data['message']['generated']}\n",
             f"- **Adherence Score:** {data['message']['adherence']['score']} {data['message']['adherence']['emoji']}",
-            f"  *{data['message']['adherence']['comment']}*\n"
+            f"  *{data['message']['adherence']['comment']}*\n",
+            "\n**Code Complexity:**\n",
+            f"- **Comment:** {data['codeComplexity']['comment']}\n",
+            "\n**SOLID Principles Analysis:**\n"
         ]
 
-        # Code complexity section
-        report.append("**Code Complexity:**\n")
-        report.append(f"- **Comment:** {data['codeComplexity']['comment']}\n")
-
-        # SOLID principles section
-        report.append("**SOLID Principles Analysis:**\n")
         for principle, details in data['codeSOLID'].items():
             report.append(f"- **{principle.replace('_', ' ').title()}**")
             report.append(f"  - **Score:** {details['score']} {details['emoji']}")
@@ -127,6 +128,23 @@ class GitIssuePublisher(Publisher):
 
         return '\n'.join(report)
 
+    def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
+        """
+        Appends adherence data to the existing comment body.
+
+        :param existing_body: The existing comment body.
+        :param adherence: A dictionary with adherence score details.
+        :return: The updated comment body.
+        """
+        adherence_line = f"| {self.sha} | {adherence['score']} {adherence['emoji']} |"
+        if "| Commit | Score |\n|--------|-------|" in existing_body:
+            updated_body = existing_body.replace(
+                "|--------|-------|", f"|--------|-------|\n{adherence_line}"
+            )
+        else:
+            updated_body = existing_body + "\n\n**Adherence Scores History:**\n| Commit | Score |\n|--------|-------|\n" + adherence_line
+        return updated_body
+
     
 
 class WebPublisher(Publisher):
